==> 0.2.24.tar.gz: ios/Classes/OnairosOverlayPlugin.swift <==
import Flutter
import UIKit
import LocalAuthentication
import Security

@objc(OnairosOverlayPlugin)
public class OnairosOverlayPlugin: NSObject, FlutterPlugin {
    @objc public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "com.onairos/overlay", binaryMessenger: registrar.messenger())
        let instance = OnairosOverlayPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }

    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        switch call.method {
        case "hasCredentials":
            result(hasCredentials())
        case "storeCredentials":
            guard let args = call.arguments as? [String: String],
                  let username = args["username"],
                  let encryptedKey = args["encryptedKey"] else {
                result(FlutterError(code: "INVALID_ARGUMENTS", message: "Invalid arguments for storing credentials", details: nil))
                return
            }
            storeCredentials(username: username, encryptedKey: encryptedKey, result: result)
        case "getUserInfo":
            getUserInfo(result: result)
        default:
            result(FlutterMethodNotImplemented)
        }
    }

    private func hasCredentials() -> Bool {
        print("Checking for existing credentials in Keychain.") // iOS Swift-side logging
        // Keychain query to check for existing credentials
        let query: [String: Any] = [
            kSecClass as String: kSecClassGenericPassword,
            kSecAttrService as String: "com.onairos.userinfo",
            kSecMatchLimit as String: kSecMatchLimitOne
        ]
        var item: CFTypeRef?
        let status = SecItemCopyMatching(query as CFDictionary, &item)
        return status == errSecSuccess
    }

    private func storeCredentials(username: String, encryptedKey: String, result: @escaping FlutterResult) {
        print("Storing credentials in Keychain for user: \(username)")

        let credentials: [String: String] = [
            "username": username,
            "encryptedKey": encryptedKey
        ]

        do {
            let jsonData = try JSONSerialization.data(withJSONObject: credentials, options: [])
            let access = SecAccessControlCreateWithFlags(nil, 
                                                        kSecAttrAccessibleWhenPasscodeSetThisDeviceOnly,
                                                        .userPresence, 
                                                        nil)
            
            let query: [String: Any] = [
                kSecClass as String: kSecClassGenericPassword,
                kSecAttrService as String: "com.onairos.userinfo",
                kSecValueData as String: jsonData,
                kSecAttrAccessControl as String: access as Any
            ]

            let status = SecItemAdd(query as CFDictionary, nil)
            if status == errSecSuccess {
                result(true)
            } else {
                result(FlutterError(code: "SECURE_STORAGE_ERROR", message: "Failed to store data in Keychain", details: nil))
            }
        } catch {
            result(FlutterError(code: "JSON_ENCODING_ERROR", message: "Failed to encode credentials as JSON", details: nil))
        }
    }


    private func getUserInfo(result: FlutterResult) {
        let query: [String: Any] = [
            kSecClass as String: kSecClassGenericPassword,
            kSecAttrService as String: "com.onairos.userinfo",
            kSecReturnData as String: true,
            kSecMatchLimit as String: kSecMatchLimitOne
        ]

        var item: CFTypeRef?
        let status = SecItemCopyMatching(query as CFDictionary, &item)
        if status == errSecSuccess {
            if let data = item as? Data {
                do {
                    if let jsonDict = try JSONSerialization.jsonObject(with: data, options: []) as? [String: String] {
                        result(jsonDict)
                    } else {
                        result(FlutterError(code: "DATA_CONVERSION_ERROR", message: "Failed to convert user info to dictionary", details: nil))
                    }
                } catch {
                    result(FlutterError(code: "JSON_PARSE_ERROR", message: "Failed to parse user info JSON", details: nil))
                }
            } else {
                result(FlutterError(code: "DATA_CONVERSION_ERROR", message: "Failed to convert user info", details: nil))
            }
        } else {
            result(FlutterError(code: "SECURE_STORAGE_ERROR", message: "Failed to retrieve user info", details: nil))
        }
    }


    private func clearCredentials(result: FlutterResult) {
        let query: [String: Any] = [
            kSecClass as String: kSecClassGenericPassword,
            kSecAttrService as String: "com.onairos.userinfo"
        ]

        let status = SecItemDelete(query as CFDictionary)
        if status == errSecSuccess || status == errSecItemNotFound {
            result(true)
        } else {
            result(FlutterError(code: "SECURE_STORAGE_ERROR", message: "Failed to clear data from Keychain", details: nil))
        }
    }


}

==> 0.2.26.tar.gz: ios/Classes/OnairosOverlayPlugin.swift <==
import Flutter
import UIKit
import LocalAuthentication
import Security

@objc(OnairosOverlayPlugin)
public class OnairosOverlayPlugin: NSObject, FlutterPlugin {
    @objc public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "com.onairos/overlay", binaryMessenger: registrar.messenger())
        let instance = OnairosOverlayPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }

    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        switch call.method {
        case "hasCredentials":
            hasCredentials(result: result)
        case "storeCredentials":
            guard let args = call.arguments as? [String: String],
                  let username = args["username"],
                  let encryptedKey = args["encryptedKey"] else {
                result(FlutterError(code: "INVALID_ARGUMENTS", message: "Invalid arguments for storing credentials", details: nil))
                return
            }
            storeCredentials(username: username, encryptedKey: encryptedKey, result: result)
        case "getUserInfo":
            getUserInfo(result: result)
        case "clearCredentials":
            clearCredentials(result: result)
        default:
            result(FlutterMethodNotImplemented)
        }
    }

    private func hasCredentials(result: FlutterResult) {
        let query: [String: Any] = [
            kSecClass as String: kSecClassGenericPassword,
            kSecAttrService as String: "com.onairos.userinfo",
            kSecReturnData as String: true,
            kSecMatchLimit as String: kSecMatchLimitOne
        ]

        var item: CFTypeRef?
        let status = SecItemCopyMatching(query as CFDictionary, &item)
        if status == errSecSuccess {
            result(true)
        } else if status == errSecItemNotFound {
            result(false)
        } else {
            result(FlutterError(code: "SECURE_STORAGE_ERROR", message: "Failed to check for data in Keychain", details: nil))
        }
    }

    private func storeCredentials(username: String, encryptedKey: String, result: @escaping FlutterResult) {
        print("Storing credentials in Keychain for user: \(username)")

        let credentials: [String: String] = [
            "username": username,
            "encryptedKey": encryptedKey
        ]

        do {
            let jsonData = try JSONSerialization.data(withJSONObject: credentials, options: [])
            let access = SecAccessControlCreateWithFlags(nil, 
                                                        kSecAttrAccessibleWhenPasscodeSetThisDeviceOnly,
                                                        .userPresence, 
                                                        nil)
            
            let query: [String: Any] = [
                kSecClass as String: kSecClassGenericPassword,
                kSecAttrService as String: "com.onairos.userinfo",
                kSecValueData as String: jsonData,
                kSecAttrAccessControl as String: access as Any
            ]

            let status = SecItemAdd(query as CFDictionary, nil)
            if status == errSecSuccess {
                result(true)
            } else {
                result(FlutterError(code: "SECURE_STORAGE_ERROR", message: "Failed to store data in Keychain", details: nil))
            }
        } catch {
            result(FlutterError(code: "JSON_ENCODING_ERROR", message: "Failed to encode credentials as JSON", details: nil))
        }
    }
    
    private func getUserInfo(result: FlutterResult) {
        let query: [String: Any] = [
            kSecClass as String: kSecClassGenericPassword,
            kSecAttrService as String: "com.onairos.userinfo",
            kSecReturnData as String: true,
            kSecMatchLimit as String: kSecMatchLimitOne
        ]

        var item: CFTypeRef?
        let status = SecItemCopyMatching(query as CFDictionary, &item)
        if status == errSecSuccess {
            if let data = item as? Data {
                do {
                    if let jsonDict = try JSONSerialization.jsonObject(with: data, options: []) as? [String: String] {
                        result(jsonDict)
                    } else {
                        result(FlutterError(code: "DATA_CONVERSION_ERROR", message: "Failed to convert user info to dictionary", details: nil))
                    }
                } catch {
                    result(FlutterError(code: "JSON_PARSE_ERROR", message: "Failed to parse user info JSON", details: nil))
                }
            } else {
                result(FlutterError(code: "DATA_CONVERSION_ERROR", message: "Failed to convert user info", details: nil))
            }
        } else {
            result(FlutterError(code: "SECURE_STORAGE_ERROR", message: "Failed to retrieve user info", details: nil))
        }
    }

    private func clearCredentials(result: FlutterResult) {
        let query: [String: Any] = [
            kSecClass as String: kSecClassGenericPassword,
            kSecAttrService as String: "com.onairos.userinfo"
        ]

        let status = SecItemDelete(query as CFDictionary)
        if status == errSecSuccess || status == errSecItemNotFound {
            result(true)
        } else {
            result(FlutterError(code: "SECURE_STORAGE_ERROR", message: "Failed to clear data from Keychain", details: nil))
        }
    }
}
